**bsmedit** is a C/C++/SystemC Visualizer.

- [Documentation](http://bsmedit.feiyilin.com)
- [PyPI](https://pypi.org/project/bsmedit/)

<img src="/docs/images/start_run_plot.gif"></img>

<img src="/docs/images/waves.gif"></img>

SystemC is licensed under SystemC Open Source License.
See [here](/systemc-2.3.1/docs/SystemC_Open_Source_License.pdf) for more details.
